@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Any, Awaitable, Callable, Dict, TypeVar, Optional
+from typing import TYPE_CHECKING, Any, Awaitable, Callable, Dict, TypeVar, Optional
 
 import discord
 from discord import app_commands
@@ -8,12 +8,16 @@ from discord.ext import commands
 
 from .database import Database
 
+if TYPE_CHECKING:
+    import datetime
+
 
 R = TypeVar('R', bound=discord.abc.Snowflake)
 
 
 class VeriBot(commands.Bot):
     app_commands_dict: Dict[str, app_commands.AppCommand]
+    startup_time: datetime.datetime
 
     def __init__(
         self,
@@ -42,16 +46,13 @@ class VeriBot(commands.Bot):
 
         await self.load_extension('veribot.commands')
         await self.load_extension('veribot.events')
+        await self.load_extension('veribot.last_sync')
         await self.load_extension('veribot.views')
         await self.load_extension('veribot.errors')
         await self.load_extension('veribot.checks')
         await self.load_extension('jishaku')
 
-        test_guild = discord.Object(id=self.guild_id)
-        self.tree.copy_global_to(guild=test_guild)
-        self.app_commands_dict = {
-            cmd.name: cmd for cmd in await self.tree.sync(guild=test_guild)
-        }
+        self.startup_time = discord.utils.utcnow()
 
     async def close(self) -> None:
         await self.db.close()
